pub struct AddressSpaceAttr(pub u32);Expand description
Address space of a pointer or global, corresponding to LLVM’s addrspace(N).
Tuple Fields
0: u32Trait Implementations
Sourceimpl Attribute for AddressSpaceAttr
impl Attribute for AddressSpaceAttr
Sourcefn get_attr_id(&self) -> AttrId
fn get_attr_id(&self) -> AttrId
Get an Attribute’s static name. This is not per instantnce.
It is mostly useful for printing and parsing the attribute.
Sourcefn get_attr_id_static() -> AttrId
fn get_attr_id_static() -> AttrId
Same as get_attr_id, but without the self reference.
Sourceimpl Clone for AddressSpaceAttr
impl Clone for AddressSpaceAttr
Sourcefn clone(&self) -> AddressSpaceAttr
fn clone(&self) -> AddressSpaceAttr
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AddressSpaceAttr
impl Debug for AddressSpaceAttr
Sourceimpl Hash for AddressSpaceAttr
impl Hash for AddressSpaceAttr
Sourceimpl Parsable for AddressSpaceAttr
impl Parsable for AddressSpaceAttr
Sourcetype Parsed = AddressSpaceAttr
type Parsed = AddressSpaceAttr
The type of the parsed entity.
Sourcefn parse<'__pliron_parse>(
state_stream: &mut StateStream<'__pliron_parse>,
arg: Self::Arg,
) -> ParseResult<'__pliron_parse, Self::Parsed>
fn parse<'__pliron_parse>( state_stream: &mut StateStream<'__pliron_parse>, arg: Self::Arg, ) -> ParseResult<'__pliron_parse, Self::Parsed>
Define a parser using existing combinators and call
into on [Parser::parse_stream] to get the final ParseResult.
Use state_stream.state as necessary.Sourceimpl PartialEq for AddressSpaceAttr
impl PartialEq for AddressSpaceAttr
Sourcefn eq(&self, other: &AddressSpaceAttr) -> bool
fn eq(&self, other: &AddressSpaceAttr) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Printable for AddressSpaceAttr
impl Printable for AddressSpaceAttr
impl Eq for AddressSpaceAttr
impl StructuralPartialEq for AddressSpaceAttr