pub struct AlignmentAttr(pub u32);Tuple Fields
0: u32Trait Implementations
Sourceimpl Attribute for AlignmentAttr
impl Attribute for AlignmentAttr
Sourcefn get_attr_id(&self) -> AttrId
fn get_attr_id(&self) -> AttrId
Get an Attribute’s static name. This is not per instantnce.
It is mostly useful for printing and parsing the attribute.
Sourcefn get_attr_id_static() -> AttrId
fn get_attr_id_static() -> AttrId
Same as get_attr_id, but without the self reference.
Sourceimpl Clone for AlignmentAttr
impl Clone for AlignmentAttr
Sourcefn clone(&self) -> AlignmentAttr
fn clone(&self) -> AlignmentAttr
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AlignmentAttr
impl Debug for AlignmentAttr
Sourceimpl Hash for AlignmentAttr
impl Hash for AlignmentAttr
Sourceimpl Parsable for AlignmentAttr
impl Parsable for AlignmentAttr
Sourcetype Parsed = AlignmentAttr
type Parsed = AlignmentAttr
The type of the parsed entity.
Sourcefn parse<'__pliron_parse>(
state_stream: &mut StateStream<'__pliron_parse>,
arg: Self::Arg,
) -> ParseResult<'__pliron_parse, Self::Parsed>
fn parse<'__pliron_parse>( state_stream: &mut StateStream<'__pliron_parse>, arg: Self::Arg, ) -> ParseResult<'__pliron_parse, Self::Parsed>
Define a parser using existing combinators and call
into on [Parser::parse_stream] to get the final ParseResult.
Use state_stream.state as necessary.Sourcefn parser<'a>(
arg: Self::Arg,
) -> Box<dyn Parser<Stream<Stream<Stream<Stream<IteratorStream<CharIterator<'a>>, SourcePosition>>>, State<'a>>, PartialState = (), Output = Self::Parsed> + 'a>
fn parser<'a>( arg: Self::Arg, ) -> Box<dyn Parser<Stream<Stream<Stream<Stream<IteratorStream<CharIterator<'a>>, SourcePosition>>>, State<'a>>, PartialState = (), Output = Self::Parsed> + 'a>
Get a parser combinator that can work on StateStream as its input.
Sourceimpl PartialEq for AlignmentAttr
impl PartialEq for AlignmentAttr
Sourceimpl Printable for AlignmentAttr
impl Printable for AlignmentAttr
impl Eq for AlignmentAttr
impl StructuralPartialEq for AlignmentAttr