pub struct CaseValuesAttr(pub Vec<IntegerAttr>);Expand description
An attribute that contains a list of case values for a switch operation.
Tuple Fields
0: Vec<IntegerAttr>Trait Implementations
Sourceimpl Attribute for CaseValuesAttr
impl Attribute for CaseValuesAttr
Sourcefn get_attr_id(&self) -> AttrId
fn get_attr_id(&self) -> AttrId
Get an Attribute’s static name. This is not per instantnce.
It is mostly useful for printing and parsing the attribute.
Sourcefn get_attr_id_static() -> AttrId
fn get_attr_id_static() -> AttrId
Same as get_attr_id, but without the self reference.
Sourceimpl Clone for CaseValuesAttr
impl Clone for CaseValuesAttr
Sourcefn clone(&self) -> CaseValuesAttr
fn clone(&self) -> CaseValuesAttr
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CaseValuesAttr
impl Debug for CaseValuesAttr
Sourceimpl Hash for CaseValuesAttr
impl Hash for CaseValuesAttr
Sourceimpl Parsable for CaseValuesAttr
impl Parsable for CaseValuesAttr
Sourcetype Parsed = CaseValuesAttr
type Parsed = CaseValuesAttr
The type of the parsed entity.
Sourcefn parse<'__pliron_parse>(
state_stream: &mut StateStream<'__pliron_parse>,
arg: Self::Arg,
) -> ParseResult<'__pliron_parse, Self::Parsed>
fn parse<'__pliron_parse>( state_stream: &mut StateStream<'__pliron_parse>, arg: Self::Arg, ) -> ParseResult<'__pliron_parse, Self::Parsed>
Define a parser using existing combinators and call
into on [Parser::parse_stream] to get the final ParseResult.
Use state_stream.state as necessary.Sourcefn parser<'a>(
arg: Self::Arg,
) -> Box<dyn Parser<Stream<Stream<Stream<Stream<IteratorStream<CharIterator<'a>>, SourcePosition>>>, State<'a>>, PartialState = (), Output = Self::Parsed> + 'a>
fn parser<'a>( arg: Self::Arg, ) -> Box<dyn Parser<Stream<Stream<Stream<Stream<IteratorStream<CharIterator<'a>>, SourcePosition>>>, State<'a>>, PartialState = (), Output = Self::Parsed> + 'a>
Get a parser combinator that can work on StateStream as its input.
Sourceimpl PartialEq for CaseValuesAttr
impl PartialEq for CaseValuesAttr
Sourceimpl Printable for CaseValuesAttr
impl Printable for CaseValuesAttr
impl Eq for CaseValuesAttr
impl StructuralPartialEq for CaseValuesAttr