pub struct FastmathFlagsAttr(pub FastmathFlags);Tuple Fields
0: FastmathFlagsTrait Implementations
Sourceimpl Attribute for FastmathFlagsAttr
impl Attribute for FastmathFlagsAttr
Sourcefn get_attr_id(&self) -> AttrId
fn get_attr_id(&self) -> AttrId
Get an Attribute’s static name. This is not per instantnce.
It is mostly useful for printing and parsing the attribute.
Sourcefn get_attr_id_static() -> AttrId
fn get_attr_id_static() -> AttrId
Same as get_attr_id, but without the self reference.
Sourceimpl Clone for FastmathFlagsAttr
impl Clone for FastmathFlagsAttr
Sourcefn clone(&self) -> FastmathFlagsAttr
fn clone(&self) -> FastmathFlagsAttr
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FastmathFlagsAttr
impl Debug for FastmathFlagsAttr
Sourceimpl Default for FastmathFlagsAttr
impl Default for FastmathFlagsAttr
Sourceimpl Display for FastmathFlagsAttr
impl Display for FastmathFlagsAttr
Sourceimpl From<FastmathFlags> for FastmathFlagsAttr
impl From<FastmathFlags> for FastmathFlagsAttr
Sourcefn from(value: FastmathFlags) -> Self
fn from(value: FastmathFlags) -> Self
Converts to this type from the input type.
Sourceimpl From<FastmathFlagsAttr> for FastmathFlags
impl From<FastmathFlagsAttr> for FastmathFlags
Sourcefn from(attr: FastmathFlagsAttr) -> Self
fn from(attr: FastmathFlagsAttr) -> Self
Converts to this type from the input type.
Sourceimpl Hash for FastmathFlagsAttr
impl Hash for FastmathFlagsAttr
Sourceimpl Parsable for FastmathFlagsAttr
impl Parsable for FastmathFlagsAttr
Sourcetype Parsed = FastmathFlagsAttr
type Parsed = FastmathFlagsAttr
The type of the parsed entity.
Sourcefn parse<'a>(
state_stream: &mut StateStream<'a>,
_arg: Self::Arg,
) -> ParseResult<'a, Self::Parsed>
fn parse<'a>( state_stream: &mut StateStream<'a>, _arg: Self::Arg, ) -> ParseResult<'a, Self::Parsed>
Define a parser using existing combinators and call
into on [Parser::parse_stream] to get the final ParseResult.
Use state_stream.state as necessary.Sourcefn parser<'a>(
arg: Self::Arg,
) -> Box<dyn Parser<Stream<Stream<Stream<Stream<IteratorStream<CharIterator<'a>>, SourcePosition>>>, State<'a>>, PartialState = (), Output = Self::Parsed> + 'a>
fn parser<'a>( arg: Self::Arg, ) -> Box<dyn Parser<Stream<Stream<Stream<Stream<IteratorStream<CharIterator<'a>>, SourcePosition>>>, State<'a>>, PartialState = (), Output = Self::Parsed> + 'a>
Get a parser combinator that can work on StateStream as its input.
Sourceimpl PartialEq for FastmathFlagsAttr
impl PartialEq for FastmathFlagsAttr
Sourceimpl Printable for FastmathFlagsAttr
impl Printable for FastmathFlagsAttr
impl Copy for FastmathFlagsAttr
impl Eq for FastmathFlagsAttr
impl StructuralPartialEq for FastmathFlagsAttr