pub struct GepNoWrapFlagsAttr(pub GepNoWrapFlags);Tuple Fields
0: GepNoWrapFlagsTrait Implementations
Sourceimpl Attribute for GepNoWrapFlagsAttr
impl Attribute for GepNoWrapFlagsAttr
Sourcefn hash_attr(&self) -> TypeValueHash
fn hash_attr(&self) -> TypeValueHash
Compute and get the hash for this instance of Self.
Hash collisions can be a possibility.
Sourcefn get_attr_id(&self) -> AttrId
fn get_attr_id(&self) -> AttrId
Get an [Attribute]’s static name. This is not per instantnce.
It is mostly useful for printing and parsing the attribute.
Sourcefn get_attr_id_static() -> AttrId
fn get_attr_id_static() -> AttrId
Same as get_attr_id, but without the self reference.
Sourceimpl Clone for GepNoWrapFlagsAttr
impl Clone for GepNoWrapFlagsAttr
Sourcefn clone(&self) -> GepNoWrapFlagsAttr
fn clone(&self) -> GepNoWrapFlagsAttr
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for GepNoWrapFlagsAttr
Sourceimpl Debug for GepNoWrapFlagsAttr
impl Debug for GepNoWrapFlagsAttr
Sourceimpl Default for GepNoWrapFlagsAttr
impl Default for GepNoWrapFlagsAttr
Sourceimpl Display for GepNoWrapFlagsAttr
impl Display for GepNoWrapFlagsAttr
impl Eq for GepNoWrapFlagsAttr
Sourceimpl From<GepNoWrapFlags> for GepNoWrapFlagsAttr
impl From<GepNoWrapFlags> for GepNoWrapFlagsAttr
Sourcefn from(value: GepNoWrapFlags) -> Self
fn from(value: GepNoWrapFlags) -> Self
Converts to this type from the input type.
Sourceimpl From<GepNoWrapFlagsAttr> for GepNoWrapFlags
impl From<GepNoWrapFlagsAttr> for GepNoWrapFlags
Sourcefn from(attr: GepNoWrapFlagsAttr) -> Self
fn from(attr: GepNoWrapFlagsAttr) -> Self
Converts to this type from the input type.
Sourceimpl Hash for GepNoWrapFlagsAttr
impl Hash for GepNoWrapFlagsAttr
Sourceimpl Parsable for GepNoWrapFlagsAttr
impl Parsable for GepNoWrapFlagsAttr
Sourcetype Parsed = GepNoWrapFlagsAttr
type Parsed = GepNoWrapFlagsAttr
The type of the parsed entity.
Sourcefn parse<'a>(
state_stream: &mut StateStream<'a>,
_arg: Self::Arg,
) -> ParseResult<'a, Self::Parsed>
fn parse<'a>( state_stream: &mut StateStream<'a>, _arg: Self::Arg, ) -> ParseResult<'a, Self::Parsed>
Define a parser using existing combinators and call
into on [Parser::parse_stream] to get the final [ParseResult].
Use state_stream.state as necessary.Sourceimpl PartialEq for GepNoWrapFlagsAttr
impl PartialEq for GepNoWrapFlagsAttr
Sourcefn eq(&self, other: &GepNoWrapFlagsAttr) -> bool
fn eq(&self, other: &GepNoWrapFlagsAttr) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Printable for GepNoWrapFlagsAttr
impl Printable for GepNoWrapFlagsAttr
impl StructuralPartialEq for GepNoWrapFlagsAttr