pub struct InsertExtractValueIndicesAttr(pub Vec<u32>);Tuple Fields
0: Vec<u32>Trait Implementations
Sourceimpl Attribute for InsertExtractValueIndicesAttr
impl Attribute for InsertExtractValueIndicesAttr
Sourcefn get_attr_id(&self) -> AttrId
fn get_attr_id(&self) -> AttrId
Get an Attribute’s static name. This is not per instantnce.
It is mostly useful for printing and parsing the attribute.
Sourcefn get_attr_id_static() -> AttrId
fn get_attr_id_static() -> AttrId
Same as get_attr_id, but without the self reference.
Sourceimpl Clone for InsertExtractValueIndicesAttr
impl Clone for InsertExtractValueIndicesAttr
Sourcefn clone(&self) -> InsertExtractValueIndicesAttr
fn clone(&self) -> InsertExtractValueIndicesAttr
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Hash for InsertExtractValueIndicesAttr
impl Hash for InsertExtractValueIndicesAttr
Sourceimpl Parsable for InsertExtractValueIndicesAttr
impl Parsable for InsertExtractValueIndicesAttr
Sourcetype Parsed = InsertExtractValueIndicesAttr
type Parsed = InsertExtractValueIndicesAttr
The type of the parsed entity.
Sourcefn parse<'__pliron_parse>(
state_stream: &mut StateStream<'__pliron_parse>,
arg: Self::Arg,
) -> ParseResult<'__pliron_parse, Self::Parsed>
fn parse<'__pliron_parse>( state_stream: &mut StateStream<'__pliron_parse>, arg: Self::Arg, ) -> ParseResult<'__pliron_parse, Self::Parsed>
Define a parser using existing combinators and call
into on [Parser::parse_stream] to get the final ParseResult.
Use state_stream.state as necessary.Sourcefn parser<'a>(
arg: Self::Arg,
) -> Box<dyn Parser<Stream<Stream<Stream<Stream<IteratorStream<CharIterator<'a>>, SourcePosition>>>, State<'a>>, PartialState = (), Output = Self::Parsed> + 'a>
fn parser<'a>( arg: Self::Arg, ) -> Box<dyn Parser<Stream<Stream<Stream<Stream<IteratorStream<CharIterator<'a>>, SourcePosition>>>, State<'a>>, PartialState = (), Output = Self::Parsed> + 'a>
Get a parser combinator that can work on StateStream as its input.
Sourceimpl PartialEq for InsertExtractValueIndicesAttr
impl PartialEq for InsertExtractValueIndicesAttr
Sourcefn eq(&self, other: &InsertExtractValueIndicesAttr) -> bool
fn eq(&self, other: &InsertExtractValueIndicesAttr) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Printable for InsertExtractValueIndicesAttr
impl Printable for InsertExtractValueIndicesAttr
impl Eq for InsertExtractValueIndicesAttr
impl StructuralPartialEq for InsertExtractValueIndicesAttr