IntegerOverflowFlagsAttr

Struct IntegerOverflowFlagsAttr 

pub struct IntegerOverflowFlagsAttr {
    pub nsw: bool,
    pub nuw: bool,
}
Integer overflow flags for arithmetic operations. The description below is from LLVM’s release notes that added the flags. “nsw” and “nuw” bits indicate that the operation is guaranteed to not overflow (in the signed or unsigned case, respectively). This gives the optimizer more information and can be used for things like C signed integer values, which are undefined on overflow.

Fields

nsw: boolnuw: bool