pub struct ShuffleVectorMaskAttr(pub Vec<i32>);Tuple Fields
0: Vec<i32>Trait Implementations
Sourceimpl Attribute for ShuffleVectorMaskAttr
impl Attribute for ShuffleVectorMaskAttr
Sourcefn get_attr_id(&self) -> AttrId
fn get_attr_id(&self) -> AttrId
Get an Attribute’s static name. This is not per instantnce.
It is mostly useful for printing and parsing the attribute.
Sourcefn get_attr_id_static() -> AttrId
fn get_attr_id_static() -> AttrId
Same as get_attr_id, but without the self reference.
Sourceimpl Clone for ShuffleVectorMaskAttr
impl Clone for ShuffleVectorMaskAttr
Sourcefn clone(&self) -> ShuffleVectorMaskAttr
fn clone(&self) -> ShuffleVectorMaskAttr
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ShuffleVectorMaskAttr
impl Debug for ShuffleVectorMaskAttr
Sourceimpl Hash for ShuffleVectorMaskAttr
impl Hash for ShuffleVectorMaskAttr
Sourceimpl Parsable for ShuffleVectorMaskAttr
impl Parsable for ShuffleVectorMaskAttr
Sourcetype Parsed = ShuffleVectorMaskAttr
type Parsed = ShuffleVectorMaskAttr
The type of the parsed entity.
Sourcefn parse<'__pliron_parse>(
state_stream: &mut StateStream<'__pliron_parse>,
arg: Self::Arg,
) -> ParseResult<'__pliron_parse, Self::Parsed>
fn parse<'__pliron_parse>( state_stream: &mut StateStream<'__pliron_parse>, arg: Self::Arg, ) -> ParseResult<'__pliron_parse, Self::Parsed>
Define a parser using existing combinators and call
into on [Parser::parse_stream] to get the final ParseResult.
Use state_stream.state as necessary.Sourcefn parser<'a>(
arg: Self::Arg,
) -> Box<dyn Parser<Stream<Stream<Stream<Stream<IteratorStream<CharIterator<'a>>, SourcePosition>>>, State<'a>>, PartialState = (), Output = Self::Parsed> + 'a>
fn parser<'a>( arg: Self::Arg, ) -> Box<dyn Parser<Stream<Stream<Stream<Stream<IteratorStream<CharIterator<'a>>, SourcePosition>>>, State<'a>>, PartialState = (), Output = Self::Parsed> + 'a>
Get a parser combinator that can work on StateStream as its input.
Sourceimpl PartialEq for ShuffleVectorMaskAttr
impl PartialEq for ShuffleVectorMaskAttr
Sourceimpl Printable for ShuffleVectorMaskAttr
impl Printable for ShuffleVectorMaskAttr
impl Eq for ShuffleVectorMaskAttr
impl StructuralPartialEq for ShuffleVectorMaskAttr