pub struct SplatAttr { /* private fields */ }Expand description
A vector constant all of whose elements are element: LLVM’s splat (...)
Implementations
Sourceimpl SplatAttr
impl SplatAttr
Sourcepub fn new(
element: Box<dyn TypedAttrInterface>,
ty: TypedHandle<VectorType>,
) -> Self
pub fn new( element: Box<dyn TypedAttrInterface>, ty: TypedHandle<VectorType>, ) -> Self
A vector constant of type ty, every element of which is element.
Sourcepub fn ty(&self) -> TypedHandle<VectorType>
pub fn ty(&self) -> TypedHandle<VectorType>
The vector type of this splat.