pub struct SymbolAddrAttr { /* private fields */ }Expand description
The address of a global variable or a function, LLVM’s ptr @symbol.
Implementations
Sourceimpl SymbolAddrAttr
impl SymbolAddrAttr
Sourcepub fn new(symbol: Identifier, ty: TypedHandle<PointerType>) -> Self
pub fn new(symbol: Identifier, ty: TypedHandle<PointerType>) -> Self
The address, of pointer type ty, of symbol — a global or a function of
the module.
Sourcepub fn ty(&self) -> TypedHandle<PointerType>
pub fn ty(&self) -> TypedHandle<PointerType>
The pointer type of this address.