pub struct ZeroAttr(pub TypeHandle);Expand description
The “zero” value of a type: a null pointer, or an all-zero-bits aggregate.
Tuple Fields
0: TypeHandleTrait Implementations
Sourceimpl Attribute for ZeroAttr
impl Attribute for ZeroAttr
Sourcefn hash_attr(&self) -> TypeValueHash
fn hash_attr(&self) -> TypeValueHash
Compute and get the hash for this instance of Self.
Hash collisions can be a possibility.
Sourcefn get_attr_id(&self) -> AttrId
fn get_attr_id(&self) -> AttrId
Get an [Attribute]’s static name. This is not per instantnce.
It is mostly useful for printing and parsing the attribute.
Sourcefn get_attr_id_static() -> AttrId
fn get_attr_id_static() -> AttrId
Same as get_attr_id, but without the self reference.
impl Eq for ZeroAttr
Sourceimpl Parsable for ZeroAttr
impl Parsable for ZeroAttr
Sourcefn parse<'__pliron_parse>(
state_stream: &mut StateStream<'__pliron_parse>,
arg: Self::Arg,
) -> ParseResult<'__pliron_parse, Self::Parsed>
fn parse<'__pliron_parse>( state_stream: &mut StateStream<'__pliron_parse>, arg: Self::Arg, ) -> ParseResult<'__pliron_parse, Self::Parsed>
Define a parser using existing combinators and call
into on [Parser::parse_stream] to get the final [ParseResult].
Use state_stream.state as necessary.Sourceimpl Printable for ZeroAttr
impl Printable for ZeroAttr
impl StructuralPartialEq for ZeroAttr