pub struct IntegerOverflowFlagsAttr {
pub nsw: bool,
pub nuw: bool,
}Expand description
Integer overflow flags for arithmetic operations. The description below is from LLVM’s release notes that added the flags. “nsw” and “nuw” bits indicate that the operation is guaranteed to not overflow (in the signed or unsigned case, respectively). This gives the optimizer more information and can be used for things like C signed integer values, which are undefined on overflow.
Fields
nsw: boolnuw: boolTrait Implementations
Sourceimpl Attribute for IntegerOverflowFlagsAttr
impl Attribute for IntegerOverflowFlagsAttr
Sourcefn get_attr_id(&self) -> AttrId
fn get_attr_id(&self) -> AttrId
Get an Attribute’s static name. This is not per instantnce.
It is mostly useful for printing and parsing the attribute.
Sourcefn get_attr_id_static() -> AttrId
fn get_attr_id_static() -> AttrId
Same as get_attr_id, but without the self reference.
Sourceimpl Clone for IntegerOverflowFlagsAttr
impl Clone for IntegerOverflowFlagsAttr
Sourcefn clone(&self) -> IntegerOverflowFlagsAttr
fn clone(&self) -> IntegerOverflowFlagsAttr
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IntegerOverflowFlagsAttr
impl Debug for IntegerOverflowFlagsAttr
Sourceimpl Default for IntegerOverflowFlagsAttr
impl Default for IntegerOverflowFlagsAttr
Sourcefn default() -> IntegerOverflowFlagsAttr
fn default() -> IntegerOverflowFlagsAttr
Returns the “default value” for a type. Read more
Sourceimpl Hash for IntegerOverflowFlagsAttr
impl Hash for IntegerOverflowFlagsAttr
Sourceimpl Parsable for IntegerOverflowFlagsAttr
impl Parsable for IntegerOverflowFlagsAttr
Sourcetype Parsed = IntegerOverflowFlagsAttr
type Parsed = IntegerOverflowFlagsAttr
The type of the parsed entity.
Sourcefn parse<'__pliron_parse>(
state_stream: &mut StateStream<'__pliron_parse>,
arg: Self::Arg,
) -> ParseResult<'__pliron_parse, Self::Parsed>
fn parse<'__pliron_parse>( state_stream: &mut StateStream<'__pliron_parse>, arg: Self::Arg, ) -> ParseResult<'__pliron_parse, Self::Parsed>
Define a parser using existing combinators and call
into on [Parser::parse_stream] to get the final ParseResult.
Use state_stream.state as necessary.Sourcefn parser<'a>(
arg: Self::Arg,
) -> Box<dyn Parser<Stream<Stream<Stream<Stream<IteratorStream<CharIterator<'a>>, SourcePosition>>>, State<'a>>, PartialState = (), Output = Self::Parsed> + 'a>
fn parser<'a>( arg: Self::Arg, ) -> Box<dyn Parser<Stream<Stream<Stream<Stream<IteratorStream<CharIterator<'a>>, SourcePosition>>>, State<'a>>, PartialState = (), Output = Self::Parsed> + 'a>
Get a parser combinator that can work on StateStream as its input.
Sourceimpl PartialEq for IntegerOverflowFlagsAttr
impl PartialEq for IntegerOverflowFlagsAttr
Sourceimpl Printable for IntegerOverflowFlagsAttr
impl Printable for IntegerOverflowFlagsAttr
Sourceimpl Verify for IntegerOverflowFlagsAttr
impl Verify for IntegerOverflowFlagsAttr
impl Eq for IntegerOverflowFlagsAttr
impl StructuralPartialEq for IntegerOverflowFlagsAttr